@@ -173,7 +173,6 @@ void LogManager::onEventsFinished(Tpl::PendingOperation *po)
     QList<AdiumThemeContentInfo> messages;
     Q_FOREACH(const Tpl::TextEventPtr &event, events) {
         AdiumThemeMessageInfo::MessageType type;
-        QString iconPath;
         Tp::ContactPtr contact;
         if(event->sender()->identifier() == m_account->normalizedName()) {
             type = AdiumThemeMessageInfo::HistoryLocalToRemote;
@@ -184,16 +183,19 @@ void LogManager::onEventsFinished(Tpl::PendingOperation *po)
             type = AdiumThemeMessageInfo::HistoryRemoteToLocal;
             contact = m_textChannel->targetContact();
         }
-        iconPath = contact->avatarData().fileName;
-
         AdiumThemeContentInfo message(type);
 
-        message.setMessage(MessageProcessor::instance()->processIncomingMessage(event).finalizedMessage());
+        if (type == AdiumThemeMessageInfo::HistoryLocalToRemote) {
+            message.setMessage(MessageProcessor::instance()->processOutgoingMessage(event).finalizedMessage());
+        } else {
+            message.setMessage(MessageProcessor::instance()->processIncomingMessage(event).finalizedMessage());
+        }
+
         message.setService(m_account->serviceName());
         message.setSenderDisplayName(event->sender()->alias());
         message.setSenderScreenName(event->sender()->alias());
         message.setTime(event->timestamp());
-        message.setUserIconPath(iconPath);
+        message.setUserIconPath(contact->avatarData().fileName);
         kDebug()    << event->timestamp()
                     << "from" << event->sender()->identifier()
                     << "to" << event->receiver()->identifier()
